@@ -91,7 +91,11 @@ void CppTree2Uml::parseTranslationUnit(const ParsedFile &file)
         QFileInfo fi(file.fileName());
 
         UMLFolder *parent = m_rootFolder;
-        QString path = fi.path().replace(m_rootPath + QLatin1String("/"), QLatin1String(""));
+        QString path;
+        if (!m_rootPath.isEmpty())
+            path = fi.path().replace(m_rootPath + QLatin1String("/"), QLatin1String(""));
+        else
+            path = fi.absolutePath();
         if (!path.isEmpty())
             parent = Import_Utils::createSubDir(path, m_rootFolder);
 
@@ -755,13 +759,17 @@ void CppTree2Uml::parseBaseClause(BaseClauseAST * baseClause, UMLClassifier* kla
     for (int i = 0; i < l.size(); ++i) {
         BaseSpecifierAST* baseSpecifier = l.at(i);
 
-        if (baseSpecifier->name() == 0) {
+        NameAST *name = baseSpecifier->name();
+        if (name == 0) {
                 uDebug() << "baseSpecifier->name() is NULL";
                 continue;
         }
-
-        QString baseName = baseSpecifier->name()->text();
-        // uDebug() << "CppTree2Uml::parseBaseClause : baseSpecifier is " << baseName;
+        ClassOrNamespaceNameAST *cons = name->unqualifiedName();
+        if (cons == 0) {
+            uDebug() << "name->unqualifiedName() is NULL";
+            continue;
+        }
+        QString baseName = cons->name()->text();
         Import_Utils::putAtGlobalScope(true);
         UMLObject *c = Import_Utils::createUMLObject(UMLObject::ot_Class, baseName,
                                                      m_currentNamespace[m_nsCnt],
